/*
	HitBlow.c
	ヒットアンドブローゲーム
*/

#include "HitBlow.h"
int main()
{
	int flg = FALSE;			//不成立状態にセット
	int status = NORMAL;		//ステータスを正常状態に設定

	printf("ゲーム開始!!!\n");

	//CPUの入力を作成
	InputCpu();

	while (flg != TRUE) {
		//ヒット数とブロー数をクリア
		ClearCount();

		printf("%d桁の数値を入力してください\n",MAX_SIZE - 1);

		while (1) {
			//プレイヤーの入力
			status = InputPlayer();

			//エラーが無い場合は、ループを抜ける
			if (status == ERROR) {
				printf("入力エラーです。\n");
				printf("%d桁の数値を入力してください\n",MAX_SIZE - 1);
				continue;
			}
			break;
		}
		//プレイヤーとCPUの数値を比較する
		flg = HitBlow(player_str, cpu_str);
	}
	printf("プログラム終了\n");

	return 0;
}
//********************************
// 関数名: InputPlayer
// 戻り値: int型 
// 引数  : なし 
// 動作  : コンソール入力処理を行う
//********************************
int InputPlayer() {
	int i;
	int j;
	int value = 0;
	int len = 0;
	int c;

	//コンソールから数値を入力する
	fgets(player_str, sizeof(player_str), stdin);

	len = strlen(player_str) - 1;
	if (player_str[len] == '\n') {
		return ERROR;
	} else {
		if (c = getchar() != '\n'){		
			while (1){
				c = getchar();
				if (c == '\n'){
					return ERROR;
				}
			}
		}
		
		//規定した文字数以外の場合は、エラーとする
		if (len+1 != MAX_SIZE - 1) {
			return ERROR;
		}

		//数値以外を入力した場合は、エラーとする
		for (i = 0; i <= len; i++) {
			if (!(player_str[i] >= '0' && player_str[i] <= '9')) {
				return ERROR;
			}
		}
	}
	value = atoi(player_str);

	//同じ文字が含まれている場合は、エラーとする
	for (i = 0; i <= len; i++) {
	    for (j = 0; j <= len; j++) {
	        if (i != j) {
	            if (player_str[i] == player_str[j]) {
	                return ERROR;
	            }
	        }
	    }
	}

	return 0;
}
//********************************
//関数名: InputCpu
//引数  : なし
//戻り値: なし
//動作  : CPUの入力を決定する
//********************************
void InputCpu() {
	//桁数用の変数の初期化
	int digit1 = 0;		//1桁目
	int digit2 = 0;		//2桁目
	int digit3 = 0;		//3桁目
	int digit4 = 0;		//4桁目

	srand((unsigned)time(NULL));

	//乱数から4桁の数値を作成
	while (1) {
		digit1 = rand() % 9;
		digit2 = rand() % 9;
		if (digit1 == digit2) {
			continue;
		}
		digit3 = rand() % 9;
		if (digit1 == digit3 || digit2 == digit3) {
			continue;
		}
		digit4 = rand() % 9;
		if (digit1 == digit4 || digit2 == digit4 || digit3 == digit4) {
			continue;
		}
		else {
			break;
		}
	}
	
	//文字列を結合
	sprintf(cpu_str, "%d%d%d%d", digit1, digit2, digit3, digit4);
	cpu_str[MAX_SIZE-1] = '\0';
}
//********************************
//関数名: Hit
//引数  : なし
//戻り値: なし
//動作  : ヒット数をカウントする
//********************************
void Hit() {
	int i;

	//プレイヤーとCPUの数値を比較し、ヒット数をカウントする
	for (i = 0; i < MAX_SIZE - 1; i++) {
		if (player_str[i] == cpu_str[i]) {
			hit_num++;
		}
	}
}
//********************************
//関数名: Blow
//引数  : なし
//戻り値: なし
//動作  : ブロー数をカウントする
//********************************
void Blow() {
	int i, j;

	//プレイヤーとCPUの数値を比較し、ブロー数をカウントする
	for (i = 0; i < MAX_SIZE - 1; i++) {
		for (j = 0; j < MAX_SIZE - 1; j++) {
			if (player_str[i] == cpu_str[j]) {
				if (i != j) {
					blow_num++;
				}
			}
		}
	}
}
//********************************
//関数名: Compare
//引数  : なし
//戻り値: int
//動作  : プレイヤーとCPUの数値を比較する
//********************************
int Compare() {
	int i;
	
	//位置と数値がすべて一致しているか判定する
    for (i = 0; i < MAX_SIZE - 1; i++) {
        if (player_str[i] != cpu_str[i]) {
            return FALSE;
        }
    }
    return TRUE;
}
//********************************
//関数名: HitBlow
//引数  : なし
//戻り値: int
//動作  : ヒットブローゲームの制御をする
//********************************
int HitBlow() {

	//4ヒットとなっているか確認する
	fin_flg = Compare();

	//4ヒットとなっている場合は、数値の比較をする
	if (fin_flg != TRUE) {
		ClearCount();
		Hit();
		Blow();
		Output();
	}

	return fin_flg;
}
//********************************
//関数名: ClearCount
//引数  : なし
//戻り値: void
//動作  : ヒット数とブロー数をクリアする
//********************************
void ClearCount() {
	hit_num = 0;
	blow_num = 0;
}
//********************************
//関数名: Output
//引数  : なし
//戻り値: void
//動作  : ヒット数とブロー数を表示する
//********************************
void Output() {
	printf("%dヒット　%dブロー\n", hit_num, blow_num);
}
//
//********************************
//関数名: DebugOut
//引数  : なし
//戻り値: void
//動作  : ヒット数とブロー数を表示する（デバッグ用）
//********************************
void DebugOut() {
	printf("player_str = %s\n", player_str);
	printf("cpu_str = %s\n", cpu_str);
}
